
# Make sure you have upgraded version of pip
Windows
```
py -m pip install --upgrade pip
```

Linux/MAC OS
```
python3 -m pip install --upgrade pip
```


# install yemot project
Windows
```
py -m pip install yemot
```

Linux/MAC OS
```
python3 -m pip install yemot
```

# How to use this project







### References
https://apisale.co.il/